
Include anti clickjacking headers
-------

**Description:**

This attack technique is commonly used by hackers to influence and manipulate users and 
their actions by means of iframes.


**Solution:**

These headers are also known as the: X-frame-Options: deny and the X-Frame-Options: 
sameorign header and provide Clickjacking protection when implemented in the application 
or webserver.

	